@@ -3,12 +3,14 @@ package OpenGuides::JSON;
 use strict;
 
 use vars qw( $VERSION );
-$VERSION = '0.02';
+$VERSION = '0.03';
 
 use Wiki::Toolkit::Plugin::JSON;
 use Time::Piece;
 use URI::Escape;
 use Carp 'croak';
+use JSON;
+use OpenGuides::CGI;
 
 sub new {
     my ( $class, @args ) = @_;
@@ -143,6 +145,13 @@ sub json_maker {
     return $self->{json_maker};
 }
 
+sub make_prefs_json {
+    my $self = shift;
+    my %prefs = OpenGuides::CGI->get_prefs_from_cookie(
+        config => $self->{config} );
+    return encode_json( \%prefs );
+}
+
 sub make_recentchanges_json {
     my ( $self, %args ) = @_;
 
@@ -245,6 +254,15 @@ all of the following metadata when calling C<write_node>:
 Returns a raw L<Wiki::Toolkit::Plugin::JSON> object created with the values you
 invoked this module with.
 
+=item B<make_prefs_json>
+
+    my $json_writer = OpenGuides::JSON->new( wiki   => $wiki,
+                                             config => $config );
+    print $json_writer->make_prefs_json();
+
+Retrieves the preferences from any stored preferences cookie, supplies
+defaults for any preferences not set, returns the result as JSON.
+
 =item B<make_recentchanges_json>
 
     # Ten most recent changes.
@@ -294,7 +312,7 @@ The OpenGuides Project (openguides-dev@openguides.org)
 
 =head1 COPYRIGHT
 
-Copyright (C) 2003-2009 The OpenGuides Project.  All Rights Reserved.
+Copyright (C) 2003-2012 The OpenGuides Project.  All Rights Reserved.
 
 This module is free software; you can redistribute it and/or modify it
 under the same terms as Perl itself.
